@@ -1,10 +1,11 @@
-import logging
 import os
+import logging
 
 from cirrocumulus.envir import CIRRO_LOG_LEVEL
 
-logger = logging.getLogger('cirro')
-log_level = os.environ.get(CIRRO_LOG_LEVEL, 'ERROR')
+
+logger = logging.getLogger("cirro")
+log_level = os.environ.get(CIRRO_LOG_LEVEL, "ERROR")
 logger.propagate = False
 logger.setLevel(log_level)
 logger.addHandler(logging.StreamHandler())  # Logs go to stderr
