@@ -2,35 +2,48 @@
 # Only methods server and datasets must be supported in 'client' mode
 import os
 
-from cirrocumulus.envir import SERVER_CAPABILITY_RENAME_CATEGORIES, SERVER_CAPABILITY_JOBS, \
-    SERVER_CAPABILITY_FEATURE_SETS, SERVER_CAPABILITY_LINKS, SERVER_CAPABILITY_EDIT_DATASET, \
-    SERVER_CAPABILITY_ADD_DATASET, SERVER_CAPABILITY_DELETE_DATASET
+from cirrocumulus.envir import (
+    SERVER_CAPABILITY_ADD_DATASET,
+    SERVER_CAPABILITY_DELETE_DATASET,
+    SERVER_CAPABILITY_EDIT_DATASET,
+    SERVER_CAPABILITY_FEATURE_SETS,
+    SERVER_CAPABILITY_JOBS,
+    SERVER_CAPABILITY_LINKS,
+    SERVER_CAPABILITY_RENAME_CATEGORIES,
+)
 
 
 def to_bool(s):
-    return s.lower() in ['true', '1']
+    return s.lower() in ["true", "1"]
 
 
 class AbstractDB:
-
     def __init__(self):
-        """Initializes the object
-
-        """
+        """Initializes the object"""
 
     def capabilities(self):  # allow everything
         c = {}
-        c[SERVER_CAPABILITY_RENAME_CATEGORIES] = to_bool(os.environ.get(SERVER_CAPABILITY_RENAME_CATEGORIES, 'True'))
-        c[SERVER_CAPABILITY_JOBS] = to_bool(os.environ.get(SERVER_CAPABILITY_JOBS, 'True'))
-        c[SERVER_CAPABILITY_FEATURE_SETS] = to_bool(os.environ.get(SERVER_CAPABILITY_FEATURE_SETS, 'True'))
-        c[SERVER_CAPABILITY_LINKS] = to_bool(os.environ.get(SERVER_CAPABILITY_LINKS, 'True'))
-        c[SERVER_CAPABILITY_EDIT_DATASET] = to_bool(os.environ.get(SERVER_CAPABILITY_EDIT_DATASET, 'True'))
-        c[SERVER_CAPABILITY_ADD_DATASET] = to_bool(os.environ.get(SERVER_CAPABILITY_ADD_DATASET, 'True'))
-        c[SERVER_CAPABILITY_DELETE_DATASET] = to_bool(os.environ.get(SERVER_CAPABILITY_DELETE_DATASET, 'True'))
+        c[SERVER_CAPABILITY_RENAME_CATEGORIES] = to_bool(
+            os.environ.get(SERVER_CAPABILITY_RENAME_CATEGORIES, "True")
+        )
+        c[SERVER_CAPABILITY_JOBS] = to_bool(os.environ.get(SERVER_CAPABILITY_JOBS, "True"))
+        c[SERVER_CAPABILITY_FEATURE_SETS] = to_bool(
+            os.environ.get(SERVER_CAPABILITY_FEATURE_SETS, "True")
+        )
+        c[SERVER_CAPABILITY_LINKS] = to_bool(os.environ.get(SERVER_CAPABILITY_LINKS, "True"))
+        c[SERVER_CAPABILITY_EDIT_DATASET] = to_bool(
+            os.environ.get(SERVER_CAPABILITY_EDIT_DATASET, "True")
+        )
+        c[SERVER_CAPABILITY_ADD_DATASET] = to_bool(
+            os.environ.get(SERVER_CAPABILITY_ADD_DATASET, "True")
+        )
+        c[SERVER_CAPABILITY_DELETE_DATASET] = to_bool(
+            os.environ.get(SERVER_CAPABILITY_DELETE_DATASET, "True")
+        )
         return c
 
     def datasets(self, email):
-        """ Gets list of available datasets
+        """Gets list of available datasets
 
         Args:
             email: User email or None
@@ -62,7 +75,7 @@ class AbstractDB:
         raise NotImplementedError()
 
     def upsert_category_name(self, email, dataset_id, category, original_value, update):
-        """ Upserts a category name.
+        """Upserts a category name.
 
         Args:
              email: User email or None
@@ -74,7 +87,7 @@ class AbstractDB:
         raise NotImplementedError()
 
     def user(self, email):
-        """ Gets metadata about a user
+        """Gets metadata about a user
 
         Args:
            email: User email
@@ -89,21 +102,21 @@ class AbstractDB:
 
     # views
     def dataset_views(self, email, dataset_id):
-        """ Gets list of saved dataset views (saved visualization states)
+        """Gets list of saved dataset views (saved visualization states)
 
-       Args:
-             email: User email or None
-             dataset_id: Dataset id
+        Args:
+              email: User email or None
+              dataset_id: Dataset id
 
-        Returns:
-            List of dicts. Example:
-            [{"id": "view id",
-              "name": "view name"}]
-       """
+         Returns:
+             List of dicts. Example:
+             [{"id": "view id",
+               "name": "view name"}]
+        """
         raise NotImplementedError()
 
     def delete_dataset_view(self, email, view_id):
-        """ Delete a saved view
+        """Delete a saved view
 
         Args:
             email: User email or None
@@ -113,7 +126,7 @@ class AbstractDB:
         raise NotImplementedError()
 
     def get_dataset_view(self, email, view_id):
-        """ Gets detailed information for a saved dataset view
+        """Gets detailed information for a saved dataset view
 
         Args:
             email: User email or None
@@ -131,7 +144,7 @@ class AbstractDB:
         raise NotImplementedError()
 
     def upsert_dataset_view(self, email, dataset_id, view):
-        """ Upserts a dataset view
+        """Upserts a dataset view
         View should have id (for update), name, value, and any other additional fields to store
 
         Args:
@@ -145,7 +158,7 @@ class AbstractDB:
         raise NotImplementedError()
 
     def delete_dataset(self, email, dataset_id):
-        """ Deletes a dataset
+        """Deletes a dataset
 
         Args:
             email: User email or None
@@ -154,7 +167,7 @@ class AbstractDB:
         raise NotImplementedError()
 
     def upsert_dataset(self, email, readers, dataset):
-        """ Upserts a dataset. If dataset.id is None then a new dataset is inserted.
+        """Upserts a dataset. If dataset.id is None then a new dataset is inserted.
         Dataset should have name, url, description, title, species, and any other additional fields to store
         Args:
               email: User email or None
@@ -167,7 +180,7 @@ class AbstractDB:
         raise NotImplementedError()
 
     def get_feature_sets(self, email, dataset_id):
-        """ Gets saved feature sets
+        """Gets saved feature sets
 
         Args:
               email: User email or None
@@ -183,7 +196,7 @@ class AbstractDB:
         raise NotImplementedError()
 
     def delete_feature_set(self, email, dataset_id, set_id):
-        """ Deletes a saved feature set
+        """Deletes a saved feature set
 
         Args:
               email: User email or None
@@ -193,7 +206,7 @@ class AbstractDB:
         raise NotImplementedError()
 
     def upsert_feature_set(self, email, dataset_id, set_id, category, name, features):
-        """ Upserts a feature set
+        """Upserts a feature set
 
         Args:
             email: User email or None
@@ -209,7 +222,7 @@ class AbstractDB:
         raise NotImplementedError()
 
     def create_job(self, email, dataset_id, job_name, job_type, params):
-        """ Creates a job
+        """Creates a job
 
         Args:
          email: User email or None
@@ -220,24 +233,24 @@ class AbstractDB:
 
         Returns:
          job id
-      """
+        """
         raise NotImplementedError()
 
     def get_job(self, email, job_id, return_type):
-        """ Gets a job
+        """Gets a job
 
-       Args:
-          email: User email or None
-          job_id: Job id
-          return_type: One of "result", "status", or "params"
+        Args:
+           email: User email or None
+           job_id: Job id
+           return_type: One of "result", "status", or "params"
 
-       Returns:
-          The job
-      """
+        Returns:
+           The job
+        """
         raise NotImplementedError()
 
     def get_jobs(self, email, dataset_id):
-        """ Gets a list of all jobs for a dataset.
+        """Gets a list of all jobs for a dataset.
 
         Args:
             email: User email or None
@@ -245,25 +258,25 @@ class AbstractDB:
 
         Returns:
             List of jobs
-      """
+        """
         raise NotImplementedError()
 
     def delete_job(self, email, job_id):
-        """ Deletes a job.
+        """Deletes a job.
 
-      Args:
-          email: User email or None
-          job_id: Job id
-      """
+        Args:
+            email: User email or None
+            job_id: Job id
+        """
         raise NotImplementedError()
 
     def update_job(self, email, job_id, status, result):
-        """ Updates job info.
+        """Updates job info.
 
-          Args:
-              email: User email or None
-              job_id: Job id
-              status: Job status
-              result: Job result
-          """
+        Args:
+            email: User email or None
+            job_id: Job id
+            status: Job status
+            result: Job result
+        """
         raise NotImplementedError()
